@@ -1,5 +1,5 @@
 
-use v6;
+use v6-alpha;
 module Motd;
 
 sub finger (@arr) returns Str is export {
