@@ -10,8 +10,8 @@ my %Cookies;
 
 sub CookiesInit() {
     %Cookies=();
-    if (%ENV{'HTTP_COOKIE'} ne '') {
-        for (split(rx:perl5/\s*;\s*/,%ENV{'HTTP_COOKIE'})) {
+    if (%*ENV{'HTTP_COOKIE'} ne '') {
+        for (split(rx:perl5/\s*;\s*/,%*ENV{'HTTP_COOKIE'})) {
             my ($p,$v)=split('=',$_);
             CookiesAdd($p,$v);
         }
