@@ -6,5 +6,5 @@ method generate_keystream(Int $n) returns Array {...}
 
 # Things we implement for them.
 method _cipher(Array $data) returns Array {
-    return *$data >>+^<< *.generate_keystream($data.elems);
+    return ($data >>+^<< *.generate_keystream($data.elems));
 }
