@@ -1,4 +1,4 @@
-use v6;
+use v6-alpha;
 
 @*MonthLengths =
     ( 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 );
