@@ -1,5 +1,4 @@
-#!/usr/bin/pugs
-use v6;
+use v6-alpha;
 
 use Locale::KeyedText;
 
@@ -15,8 +14,7 @@ module MyLib {
                 msg_key => 'MYLIB_MYINV_BAD_ARG',
                 msg_vars => { 'GIVEN_VALUE' => $number },
             )
-#            if $number !~ m/^-?(\d+\.?|\d*\.\d+)$/; # integer or decimal
-            if $number !~ m:perl5/^-?(\d+\.?|\d*\.\d+)$/; #: inte or deci
+            if $number !~~ m/^-?(\d+\.?|\d*\.\d+)$/; # integer or decimal
         die Locale::KeyedText::Message.new(
                 msg_key => 'MYLIB_MYINV_RES_INF' )
             if $number == 0;
