@@ -1,5 +1,4 @@
-#!/usr/bin/pugs
-use v6;
+use v6-alpha;
 
 # External packages used by packages in this file, that don't export symbols:
 # (None Yet)
@@ -13,7 +12,7 @@ my Str $EMPTY_STR is readonly = q{};
 ###########################################################################
 ###########################################################################
 
-package Locale::KeyedText-1.73.0 {
+package Locale::KeyedText-1.73.1 {
     # Note: This given version applies to all of this file's packages.
 } # package Locale::KeyedText
 
@@ -37,8 +36,8 @@ class Locale::KeyedText::Message {
 
 submethod BUILD (Str :$msg_key!, Any :%msg_vars? = {}) {
 
-    $?SELF!_assert_arg_str( 'new', ':$msg_key!', $msg_key );
-    $?SELF!_assert_arg_hash( 'new', ':%msg_vars?', %msg_vars );
+    self!_assert_arg_str( 'new', ':$msg_key!', $msg_key );
+    self!_assert_arg_hash( 'new', ':%msg_vars?', %msg_vars );
 
     $!msg_key  = $msg_key;
     %!msg_vars = %msg_vars;
@@ -62,7 +61,7 @@ method get_msg_key () returns Str {
 }
 
 method get_msg_var (Str $var_name!) returns Any {
-    $?SELF!_assert_arg_str( 'get_msg_var', '$var_name!', $var_name );
+    self!_assert_arg_str( 'get_msg_var', '$var_name!', $var_name );
     return %!msg_vars{$var_name};
 }
 
@@ -95,19 +94,19 @@ my method _die_with_msg (Str $msg_key!, Any %msg_vars? is ref = {}) {
 }
 
 my method _assert_arg_str (Str $meth!, Str $arg!, Str $val!) {
-    $?SELF!_die_with_msg( 'LKT_ARG_UNDEF',
+    self!_die_with_msg( 'LKT_ARG_UNDEF',
             { 'METH' => $meth, 'ARG' => $arg } )
         if !$val.defined;
-    $?SELF!_die_with_msg( 'LKT_ARG_EMP_STR',
+    self!_die_with_msg( 'LKT_ARG_EMP_STR',
             { 'METH' => $meth, 'ARG' => $arg } )
         if $val eq $EMPTY_STR;
 }
 
 my method _assert_arg_hash (Str $meth!, Str $arg!, Any %val!) {
-    $?SELF!_die_with_msg( 'LKT_ARG_UNDEF',
+    self!_die_with_msg( 'LKT_ARG_UNDEF',
             { 'METH' => $meth, 'ARG' => $arg } )
         if !%val.defined;
-    $?SELF!_die_with_msg( 'LKT_ARG_HASH_KEY_EMP_STR',
+    self!_die_with_msg( 'LKT_ARG_HASH_KEY_EMP_STR',
             { 'METH' => $meth, 'ARG' => $arg } )
         if %val.exists($EMPTY_STR);
 }
@@ -136,8 +135,8 @@ class Locale::KeyedText::Translator {
 
 submethod BUILD (Str :@set_names!, Str :@member_names!) {
 
-    $?SELF!_assert_arg_ary( 'new', ':@set_names!', @set_names );
-    $?SELF!_assert_arg_ary( 'new', ':@member_names!', @member_names );
+    self!_assert_arg_ary( 'new', ':@set_names!', @set_names );
+    self!_assert_arg_ary( 'new', ':@member_names!', @member_names );
 
     @!set_names    = @set_names;
     @!member_names = @member_names;
@@ -189,7 +188,7 @@ method get_set_member_combinations () returns Array of Str {
 method translate_message (Locale::KeyedText::Message $message!)
         returns Str {
 
-    $?SELF!_assert_arg_msg( 'translate_message', '$message!', $message );
+    self!_assert_arg_msg( 'translate_message', '$message!', $message );
 
     # This Perl-6 specific workaround is done since $message param can oft
     # be set from a caught exception (aliased to $!), and the Perl-6 spec
@@ -200,7 +199,7 @@ method translate_message (Locale::KeyedText::Message $message!)
 
     my Str $text = undef;
 #    SET_MEMBER:
-    for @{.get_set_member_combinations()} -> $module_name {
+    for .get_set_member_combinations()[] -> $module_name {
         # Determine if requested template module is already loaded.
         # It may have been embedded in a core program file and hence
         # should never be loaded by translate_message().
@@ -211,7 +210,7 @@ method translate_message (Locale::KeyedText::Message $message!)
         # and so skip to the next candidate module name.
         if (!$module_is_loaded) {
             try {
-                $?SELF.load_template_module( $module_name );
+                self.load_template_module( $module_name );
             };
 #            next SET_MEMBER
             next
@@ -242,11 +241,11 @@ method translate_message (Locale::KeyedText::Message $message!)
 ###########################################################################
 
 method template_module_is_loaded (Str $module_name!) returns Bool {
-    $?SELF!_assert_arg_str( 'template_module_is_loaded',
+    self!_assert_arg_str( 'template_module_is_loaded',
         '$module_name!', $module_name );
     # Note: It is yet unknown whether this is working because the language
     # spec says it is supposed to, or whether is due a fluke or unspecced.
-    # Currently, "::($m).ref" returns 'Type' if the package name in $m is
+    # Currently, "::($m).WHAT" returns 'Type' if the package name in $m is
     # not loaded, and it returns one of ['Class','Module', etc] if it is.
     # Note: 'Package' is checked for instead of 'Module' since all types of
     # packages share the same namespace; any incompat will be caught later.
@@ -255,14 +254,14 @@ method template_module_is_loaded (Str $module_name!) returns Bool {
 
 method load_template_module (Str $module_name!) {
 
-    $?SELF!_assert_arg_str( 'load_template_module',
+    self!_assert_arg_str( 'load_template_module',
         '$module_name!', $module_name );
 
     # Note: We have to invoke this 'require' in an eval string
     # because we need the bareword semantics, where 'require'
     # will munge the package name into file system paths.
     eval "require $module_name;";
-    $?SELF!_die_with_msg( 'LKT_T_FAIL_LOAD_TMPL_MOD',
+    self!_die_with_msg( 'LKT_T_FAIL_LOAD_TMPL_MOD',
             { 'METH' => 'load_template_module',
             'TMPL_MOD_NAME' => $module_name, 'REASON' => $! } )
         if $!;
@@ -273,16 +272,16 @@ method load_template_module (Str $module_name!) {
 method get_template_text_from_loaded_module
         (Str $module_name!, Str $msg_key!) returns Str {
 
-    $?SELF!_assert_arg_str( 'get_template_text_from_loaded_module',
+    self!_assert_arg_str( 'get_template_text_from_loaded_module',
         '$module_name!', $module_name );
-    $?SELF!_assert_arg_str( 'get_template_text_from_loaded_module',
+    self!_assert_arg_str( 'get_template_text_from_loaded_module',
         '$msg_key!', $msg_key );
 
     my Str $text = undef;
     try {
         $text = &::($module_name)::get_text_by_key( $msg_key );
     };
-    $?SELF!_die_with_msg( 'LKT_T_FAIL_GET_TMPL_TEXT',
+    self!_die_with_msg( 'LKT_T_FAIL_GET_TMPL_TEXT',
             { 'METH' => 'get_template_text_from_loaded_module',
             'TMPL_MOD_NAME' => $module_name, 'REASON' => $! } )
         if $!;
@@ -293,17 +292,16 @@ method get_template_text_from_loaded_module
 method interpolate_vars_into_template_text
         (Str $text! is copy, Any %msg_vars!) returns Str {
 
-    $?SELF!_die_with_msg( 'LKT_ARG_UNDEF',
+    self!_die_with_msg( 'LKT_ARG_UNDEF',
             { 'METH' => 'interpolate_vars_into_template_text',
             'ARG' => '$text!' } )
         if !$text.defined;
-    $?SELF!_assert_arg_hash( 'interpolate_vars_into_template_text',
+    self!_assert_arg_hash( 'interpolate_vars_into_template_text',
         '%msg_vars!', %msg_vars );
 
     for %msg_vars.kv -> $var_name, $var_value {
-        my Str $var_value_as_str = $var_value // $EMPTY_STR; #/
-#        $text ~~ s:g/\<$var_name\>/$var_value_as_str/; #: v req PGE/Parrot
-        $text ~~ s:perl5:g/\<$var_name\>/$var_value_as_str/; #: v req Pugs
+        my Str $var_value_as_str = $var_value // $EMPTY_STR;
+        $text ~~ s:g/\<$var_name\>/$var_value_as_str/;
     }
 
     return $text;
@@ -318,45 +316,45 @@ my method _die_with_msg (Str $msg_key!, Any %msg_vars? is ref = {}) {
 }
 
 my method _assert_arg_str (Str $meth!, Str $arg!, Str $val!) {
-    $?SELF!_die_with_msg( 'LKT_ARG_UNDEF',
+    self!_die_with_msg( 'LKT_ARG_UNDEF',
             { 'METH' => $meth, 'ARG' => $arg } )
         if !$val.defined;
-    $?SELF!_die_with_msg( 'LKT_ARG_EMP_STR',
+    self!_die_with_msg( 'LKT_ARG_EMP_STR',
             { 'METH' => $meth, 'ARG' => $arg } )
         if $val eq $EMPTY_STR;
 }
 
 my method _assert_arg_ary (Str $meth!, Str $arg!, Str @val!) {
-    $?SELF!_die_with_msg( 'LKT_ARG_UNDEF',
+    self!_die_with_msg( 'LKT_ARG_UNDEF',
             { 'METH' => $meth, 'ARG' => $arg } )
         if !@val.defined;
-    $?SELF!_die_with_msg( 'LKT_ARG_ARY_NO_ELEMS',
+    self!_die_with_msg( 'LKT_ARG_ARY_NO_ELEMS',
             { 'METH' => $meth, 'ARG' => $arg } )
         if +@val == 0;
     for @val -> $val_elem {
-        $?SELF!_die_with_msg( 'LKT_ARG_ARY_ELEM_UNDEF',
+        self!_die_with_msg( 'LKT_ARG_ARY_ELEM_UNDEF',
                 { 'METH' => $meth, 'ARG' => $arg } )
             if !$val_elem.defined;
-        $?SELF!_die_with_msg( 'LKT_ARG_ARY_ELEM_EMP_STR',
+        self!_die_with_msg( 'LKT_ARG_ARY_ELEM_EMP_STR',
                 { 'METH' => $meth, 'ARG' => $arg } )
             if $val_elem eq $EMPTY_STR;
     }
 }
 
 my method _assert_arg_hash (Str $meth!, Str $arg!, Any %val!) {
-    $?SELF!_die_with_msg( 'LKT_ARG_UNDEF',
+    self!_die_with_msg( 'LKT_ARG_UNDEF',
             { 'METH' => $meth, 'ARG' => $arg } )
         if !%val.defined;
-    $?SELF!_die_with_msg( 'LKT_ARG_HASH_KEY_EMP_STR',
+    self!_die_with_msg( 'LKT_ARG_HASH_KEY_EMP_STR',
             { 'METH' => $meth, 'ARG' => $arg } )
         if %val.exists($EMPTY_STR);
 }
 
 my method _assert_arg_msg (Str $meth!, Str $arg!, $val!) {
-    $?SELF!_die_with_msg( 'LKT_ARG_UNDEF',
+    self!_die_with_msg( 'LKT_ARG_UNDEF',
             { 'METH' => $meth, 'ARG' => $arg } )
         if !$val.defined;
-    $?SELF!_die_with_msg( 'LKT_ARG_NO_EXP_TYPE', { 'METH' => $meth,
+    self!_die_with_msg( 'LKT_ARG_NO_EXP_TYPE', { 'METH' => $meth,
             'ARG' => $arg, 'EXP_TYPE' => 'Locale::KeyedText::Message',
             'VAL' => $val } )
         if !$val.does(Locale::KeyedText::Message);
@@ -380,7 +378,7 @@ Refer to user messages in programs by keys
 
 =head1 VERSION
 
-This document describes Locale::KeyedText version 1.73.0.
+This document describes Locale::KeyedText version 1.73.1.
 
 It also describes the same-number versions of Locale::KeyedText::Message
 ("Message") and Locale::KeyedText::Translator ("Translator").
@@ -654,7 +652,7 @@ This is the main Message constructor method:
 
 This method creates and returns a new Locale::KeyedText::Message object.
 The Message Key attribute of the new object is set from the named parameter
-$msg_key (a string); the optional named parameter %msg_vars (a hash ref)
+$msg_key (a string); the optional named parameter %msg_vars (a hash)
 sets the "Message Variables" attribute if the corresponding argument is
 provided (it defaults to empty if the argument is not provided).
 
@@ -682,7 +680,7 @@ A Message object has these methods:
 
 =item C<export_as_hash()>
 
-This method returns a deep copy of this Message as a Hash ref of 2
+This method returns a deep copy of this Message as a Hash of 2
 elements, which correspond to the 2 named parameters of new().
 
 =item C<get_msg_key()>
@@ -698,7 +696,7 @@ string).
 =item C<get_msg_vars()>
 
 This method returns all Message Variable names and values of this object as
-a hash ref.
+a hash.
 
 =item C<as_debug_string()>
 
@@ -836,8 +834,8 @@ This is the main Translator constructor method:
 
 This method creates and returns a new Locale::KeyedText::Translator object.
 The Set Names property of the new object is set from the named parameter
-@set_names (an array ref), and Member Names is set from the named parameter
-@member_names (an array ref).
+@set_names (an array), and Member Names is set from the named parameter
+@member_names (an array).
 
 Some example usage:
 
@@ -860,17 +858,16 @@ A Translator object has these methods:
 
 =item C<export_as_hash()>
 
-This method returns a deep copy of this Translator as a Hash ref of 2
+This method returns a deep copy of this Translator as a Hash of 2
 elements, which correspond to the 2 named parameters of new().
 
 =item C<get_set_names()>
 
-This method returns all Set Names elements in this object as an array ref.
+This method returns all Set Names elements in this object as an array.
 
 =item C<get_member_names()>
 
-This method returns all Member Names elements in this object as an array
-ref.
+This method returns all Member Names elements in this object as an array.
 
 =item C<as_debug_string()>
 
@@ -882,7 +879,7 @@ coercing this object to a string.
 
 =item C<get_set_member_combinations()>
 
-This method returns an array ref having all combinations of this object's
+This method returns an array having all combinations of this object's
 Set Names and Member Names elements, concatenated in the form
 "<Set><Member>".  All combinations having the same Member Name are adjacent
 to each other in the output; for example, with Sets of ['MyApp','MyLib']
@@ -934,7 +931,7 @@ string if the module recognizes $msg_key, and the undefined value if not.
 =item C<interpolate_vars_into_template_text( $text!, %msg_vars! )>
 
 This method takes a defined (but possibly empty) Template text string in
-its positional parameter $text (a string), and a Message Variables hash ref
+its positional parameter $text (a string), and a Message Variables hash
 in its positional parameter %msg_vars.  It returns a copy of $text modified
 by interpolating the %msg_vars into it, where each variable value is
 substituted for any occurance of its corresponding variable name that is
