@@ -1,5 +1,4 @@
-#!/usr/bin/pugs
-use v6;
+use v6-alpha;
 
 ###########################################################################
 ###########################################################################
@@ -11,64 +10,64 @@ my Str %TEXT_STRINGS is readonly = (
     'LKT_ARG_UNDEF'
         => q[<CLASS>.<METH>(): argument <ARG> is undefined (or missing).],
     'LKT_ARG_NO_ARY'
-        => q[<CLASS>.<METH>(): argument <ARG> is not an Array ref,]
+        => q[<CLASS>.<METH>(): argument <ARG> is not an Array object,]
            ~ q[ but rather contains '<VAL>'.],
     'LKT_ARG_NO_HASH'
-        => q[<CLASS>.<METH>(): argument <ARG> is not a Hash ref,]
+        => q[<CLASS>.<METH>(): argument <ARG> is not a Hash object,]
            ~ q[ but rather contains '<VAL>'.],
     'LKT_ARG_NO_EXP_TYPE'
         => q[<CLASS>.<METH>(): argument <ARG> is not a <EXP_TYPE>,]
            ~ q[ but rather contains '<VAL>'.],
 
     'LKT_ARG_ARY_ELEM_UNDEF'
-        => q[<CLASS>.<METH>(): argument <ARG> is an Array ref as expected,]
+        => q[<CLASS>.<METH>(): argument <ARG> is an Array object as expected,]
            ~ q[ but one of its elements is undefined.],
     'LKT_ARG_ARY_ELEM_NO_ARY'
-        => q[<CLASS>.<METH>(): argument <ARG> is an Array ref as expected,]
-           ~ q[ but one of its elements is not an Array ref,]
+        => q[<CLASS>.<METH>(): argument <ARG> is an Array object as expected,]
+           ~ q[ but one of its elements is not an Array object,]
            ~ q[ but rather contains '<VAL>'.],
     'LKT_ARG_ARY_ELEM_NO_HASH'
-        => q[<CLASS>.<METH>(): argument <ARG> is an Array ref as expected,]
-           ~ q[ but one of its elements is not a Hash ref,]
+        => q[<CLASS>.<METH>(): argument <ARG> is an Array object as expected,]
+           ~ q[ but one of its elements is not a Hash object,]
            ~ q[ but rather contains '<VAL>'.],
     'LKT_ARG_ARY_ELEM_NO_EXP_TYPE'
-        => q[<CLASS>.<METH>(): argument <ARG> is an Array ref as expected,]
+        => q[<CLASS>.<METH>(): argument <ARG> is an Array object as expected,]
            ~ q[ but one of its elements is not a <EXP_TYPE>,]
            ~ q[ but rather contains '<VAL>'.],
 
     'LKT_ARG_HASH_VAL_UNDEF'
-        => q[<CLASS>.<METH>(): argument <ARG> is a Hash ref as expected,]
+        => q[<CLASS>.<METH>(): argument <ARG> is a Hash object as expected,]
            ~ q[ but the value for its '<KEY>' key is undefined.],
     'LKT_ARG_HASH_VAL_NO_ARY'
-        => q[<CLASS>.<METH>(): argument <ARG> is a Hash ref as expected,]
-           ~ q[ but the value for its '<KEY>' key is not an Array ref,]
+        => q[<CLASS>.<METH>(): argument <ARG> is a Hash object as expected,]
+           ~ q[ but the value for its '<KEY>' key is not an Array object,]
            ~ q[ but rather contains '<VAL>'.],
     'LKT_ARG_HASH_VAL_NO_HASH'
-        => q[<CLASS>.<METH>(): argument <ARG> is a Hash ref as expected,]
-           ~ q[ but the value for its '<KEY>' key is not a Hash ref,]
+        => q[<CLASS>.<METH>(): argument <ARG> is a Hash object as expected,]
+           ~ q[ but the value for its '<KEY>' key is not a Hash object,]
            ~ q[ but rather contains '<VAL>'.],
     'LKT_ARG_HASH_VAL_NO_EXP_TYPE'
-        => q[<CLASS>.<METH>(): argument <ARG> is a Hash ref as expected,]
+        => q[<CLASS>.<METH>(): argument <ARG> is a Hash object as expected,]
            ~ q[ but the value for its '<KEY>' key is not a <EXP_TYPE>,]
            ~ q[ but rather contains '<VAL>'.],
 
     'LKT_ARG_ARY_NO_ELEMS'
-        => q[<CLASS>.<METH>(): argument <ARG> is an Array ref as expected,]
+        => q[<CLASS>.<METH>(): argument <ARG> is an Array object as expected,]
            ~ q[ but it has no elements.],
     'LKT_ARG_HASH_NO_ELEMS'
-        => q[<CLASS>.<METH>(): argument <ARG> is a Hash ref as expected,]
+        => q[<CLASS>.<METH>(): argument <ARG> is a Hash object as expected,]
            ~ q[ but it has no elements.],
 
     'LKT_ARG_EMP_STR'
         => q[<CLASS>.<METH>(): argument <ARG> is an empty string.],
     'LKT_ARG_ARY_ELEM_EMP_STR'
-        => q[<CLASS>.<METH>(): argument <ARG> is an Array ref as expected,]
+        => q[<CLASS>.<METH>(): argument <ARG> is an Array object as expected,]
            ~ q[ but one of its elements is an empty string.],
     'LKT_ARG_HASH_KEY_EMP_STR'
-        => q[<CLASS>.<METH>(): argument <ARG> is a Hash ref as expected,]
+        => q[<CLASS>.<METH>(): argument <ARG> is a Hash object as expected,]
            ~ q[ but one of its keys is an empty string.],
     'LKT_ARG_HASH_VAL_EMP_STR'
-        => q[<CLASS>.<METH>(): argument <ARG> is a Hash ref as expected,]
+        => q[<CLASS>.<METH>(): argument <ARG> is a Hash object as expected,]
            ~ q[ but the value for its '<KEY>' key is an empty string.],
 
     # This group of strings is specific to Locale::KeyedText itself:
@@ -85,7 +84,7 @@ my Str %TEXT_STRINGS is readonly = (
 ###########################################################################
 ###########################################################################
 
-module Locale::KeyedText::L::en-1.0.1 {
+module Locale::KeyedText::L::en-1.0.2 {
     sub get_text_by_key (Str $msg_key!) returns Str {
         return %TEXT_STRINGS{$msg_key};
     }
@@ -105,7 +104,7 @@ Localization of Locale::KeyedText for English
 
 =head1 VERSION
 
-This document describes Locale::KeyedText::L::en version 1.0.1.
+This document describes Locale::KeyedText::L::en version 1.0.2.
 
 =head1 SYNOPSIS
 
