@@ -1,9 +1,8 @@
-#!/usr/bin/pugs
-use v6;
+use v6-alpha;
 
 # External packages used by packages in this file, that don't export symbols:
 use Locale::KeyedText-(1.72.0...);
-use Rosetta::Model-(0.724.0);
+use Rosetta::Model-(0.724.1);
 
 ###########################################################################
 ###########################################################################
@@ -14,7 +13,7 @@ use Rosetta::Model-(0.724.0);
 ###########################################################################
 ###########################################################################
 
-package Rosetta-0.724.0 {
+package Rosetta-0.724.1 {
     # Note: This given version applies to all of this file's packages.
 } # package Rosetta
 
@@ -136,7 +135,7 @@ Rigorous database portability
 
 =head1 VERSION
 
-This document describes Rosetta version 0.724.0.
+This document describes Rosetta version 0.724.1.
 
 It also describes the same-number versions of Rosetta::Interface::DBMS
 ("DBMS"), Rosetta::Interface::Exception ("Exception"),
@@ -581,7 +580,7 @@ It also requires these Perl 6 classes that are on CPAN:
 L<Locale::KeyedText-(1.72.0...)|Locale::KeyedText> (for error messages).
 
 It also requires these Perl 6 classes that are in the current distribution:
-L<Rosetta::Model-(0.724.0)|Rosetta::Model>.
+L<Rosetta::Model-(0.724.1)|Rosetta::Model>.
 
 =head1 INCOMPATIBILITIES
 
