@@ -1,9 +1,8 @@
-#!/usr/bin/pugs
-use v6;
+use v6-alpha;
 
 # External packages used by packages in this file, that don't export symbols:
 use Locale::KeyedText-(1.72.0...);
-use Rosetta-0.724.0;
+use Rosetta-0.724.1;
 
 ###########################################################################
 ###########################################################################
@@ -14,7 +13,7 @@ use Rosetta-0.724.0;
 ###########################################################################
 ###########################################################################
 
-module Rosetta::Validator-0.724.0 {
+module Rosetta::Validator-0.724.1 {
 
     # External packages used by the Rosetta::Validator module, that do export symbols:
     # (None Yet)
@@ -44,7 +43,7 @@ A common comprehensive test suite to run against all Engines
 
 =head1 VERSION
 
-This document describes Rosetta::Validator version 0.724.0.
+This document describes Rosetta::Validator version 0.724.1.
 
 =head1 SYNOPSIS
 
@@ -74,7 +73,7 @@ It also requires these Perl 6 classes that are on CPAN:
 L<Locale::KeyedText-(1.72.0...)|Locale::KeyedText> (for error messages).
 
 It also requires these Perl 6 classes that are in the current distribution:
-L<Rosetta-0.724.0|Rosetta>.
+L<Rosetta-0.724.1|Rosetta>.
 
 =head1 INCOMPATIBILITIES
 
