@@ -1,5 +1,4 @@
-#!/usr/bin/pugs
-use v6;
+use v6-alpha;
 
 ###########################################################################
 ###########################################################################
@@ -11,7 +10,7 @@ my Str %TEXT_STRINGS is readonly = (
 ###########################################################################
 ###########################################################################
 
-module Rosetta::Validator::L::en-0.160.1 {
+module Rosetta::Validator::L::en-0.160.2 {
     sub get_text_by_key (Str $msg_key!) returns Str {
         return %TEXT_STRINGS{$msg_key};
     }
@@ -31,7 +30,7 @@ Localization of Rosetta::Validator for English
 
 =head1 VERSION
 
-This document describes Rosetta::Validator::L::en version 0.160.1.
+This document describes Rosetta::Validator::L::en version 0.160.2.
 
 =head1 SYNOPSIS
 
