@@ -1,5 +1,4 @@
-#!/usr/bin/pugs
-use v6;
+use v6-alpha;
 
 # XXX LWP::Debug to debug things :-)
 #use LWP::Debug;
@@ -28,11 +27,11 @@ class HTTP::Cookies-0.0.1 {
     
     ## Creation and destruction
     submethod BUILD (Str $.file, Bool $.autosave = 0, Bool $.ignore_discard = 0, Bool $.hide_cookie2 = 0) {
-        ./load();
+        self.load();
     }
     
     submethod DESTROY () {
-        ./save() if $.autosave;
+        self.save() if $.autosave;
     }
     
     ## Instance methods
@@ -45,17 +44,17 @@ class HTTP::Cookies-0.0.1 {
             return;
         }
     
-        my $domain = ./:host($request, $uri);
+        my $domain = self!host($request, $uri);
         $domain = "$domain\.local" unless $domain ~~ m:P5/\./;
         
         my $secure_request = ($scheme eq 'https');
         
-        my $req_path = ./:uri_path($uri);
+        my $req_path = self!uri_path($uri);
         my $req_port = $uri.port;
         
         my $now = time();
         
-        ./:normalize_path($req_path) if $req_path ~~ m:P5/%/;
+        self!normalize_path($req_path) if $req_path ~~ m:P5/%/;
         
         my $set_ver = 0;
         my $netscape_only = 0; # an exact domain match applies to "any" cookie
@@ -70,7 +69,7 @@ class HTTP::Cookies-0.0.1 {
                 if (.delayload && defined $cookies{'//+delayload'}) {
                     my $data = $cookies{''//+delayload'}{'cookie'};
                     %!cookies.delete($domain);
-                    ./load_cookie($data[1]);
+                    self.load_cookie($data[1]);
                     
                     $cookies = %!cookies{$domain};
                     next unless $cookies; # should not really happen
@@ -192,10 +191,10 @@ class HTTP::Cookies-0.0.1 {
     
     # XXX lots of potential `where /.../` clauses here :-)
     method set_cookie (Num $version, Str $key, Str $val, Str $path, Str $domain, Str $port?, Bool $path_spec = Bool::False, Bool $secure = Bool::False, Num $maxage?, Bool $discard = Bool::False, *%rest) {
-        return $?SELF if $path !~ m,^/, || $key ~~ m,^\$,;
+        return self if $path !~~ m,^/, || $key ~~ m,^\$,;
         
         if $port.defined {
-            return $?SELF unless $port ~~ m:P5/^_?\d+(?:,\d+)*/;
+            return self unless $port ~~ m:P5/^_?\d+(?:,\d+)*/;
         }
         
         my $expires;
@@ -203,19 +202,19 @@ class HTTP::Cookies-0.0.1 {
         if $maxage.defined {
             if $maxage <= 0 {
                 %!cookies{$domain}{$path}.delete($key);
-                return $?SELF;
+                return self;
             }
             
             $expires = time() + $maxage;
         }
         
         my @array = ($version, $val, $port, $path_spec, $secure, $expires, $discard);
-        @array.push(*%rest) if %rest.keys;
+        @array.push(%rest) if %rest.keys;
         
         @array.pop while !defined @array[-1];
         
         %!cookies{$domain}{$path}{$key} = \@array;
-        return $?SELF;
+        return self;
     }
     
     method set_cookie_ok (*@_) { 1; }
@@ -224,7 +223,7 @@ class HTTP::Cookies-0.0.1 {
         my $fh = open($file, :w);
         
         $fh.say("#LWP-Cookies-1.0");
-        $fh.print(./as_string(!$.ignore_discard));
+        $fh.print(self.as_string(!$.ignore_discard));
         $fh.close;
         
         1;
@@ -270,13 +269,13 @@ class HTTP::Cookies-0.0.1 {
     }
     
     method revert () {
-        ./clear.load;
+        self.clear.load;
     }
     
     multi method clear () {
         %!cookies = ();
         
-        $?SELF;
+        self;
     }
     
     multi method clear (*@_) {
@@ -288,18 +287,18 @@ class HTTP::Cookies-0.0.1 {
             %!cookies{@_[0]}{@_[1]}.delete(@_[2]);
         }
         
-        $?SELF;
+        self;
     }
     
     method clear_temporary_cookies () {
-        ./scan(sub (*@_) { if (@_[9]) || (!@_[8].defined) { @_[8] = -1; ./set_cookie(*@_); } });
+        self.scan(sub (*@_) { if (@_[9]) || (!@_[8].defined) { @_[8] = -1; self.set_cookie(|@_); } });
     }
     
     method scan (Code $callback) {
         for %!cookies.keys.sort -> $domain {
             for %!cookies{$domain}.keys.sort -> $path {
                 for %!cookies{$domain}{$path}.keys.sort -> $key is rw {
-                    my :($version, $val, $port, $path_spec, $secure, $expires, $discard, *%rest) := @{$key};
+                    my :($version, $val, $port, $path_spec, $secure, $expires, $discard, *%rest) := @$key;
                     %rest //= {};
                     
                     $cb.($version, $key, $val, $path, $domain, $port, $path_spec, $secure, $expires, $discard, *%rest);
@@ -311,7 +310,7 @@ class HTTP::Cookies-0.0.1 {
     method as_string (Bool $skip_discardables?) {
         # XXX use nested gather/take
         my @ret = (gather {
-            ./scan(sub ($version, $key, $val, $path, $domain, $port?, $path_spec?, $secure?, $maxage?, $discard?, *%rest) {
+            self.scan(sub ($version, $key, $val, $path, $domain, $port?, $path_spec?, $secure?, $maxage?, $discard?, *%rest) {
                 return if $discard && $skip_discardables;
                 
                 my @h = ($key, $val);
