@@ -1,5 +1,4 @@
-#!/usr/bin/pugs
-use v6;
+use v6-alpha;
 
 module HTTP::Status-0.0.1 {
     my %StatusCode = (
