@@ -46,7 +46,7 @@ use strict;
 
   sub as_js {
     my $key = ref $_[0]->{key}
-      ? sprintf "PIL2JS.cps2normal(_26main_3a_3aprefix_3a_7e.FETCH(), [PIL2JS.Context.ItemAny, %s]).toNative()", $_[0]->{key}->as_js
+      ? sprintf "PIL2JS.cps2normal(_26Main_3a_3aprefix_3a_7e.FETCH(), [PIL2JS.Context.ItemAny, %s]).toNative()", $_[0]->{key}->as_js
       : PIL::doublequote($_[0]->{key});
     sprintf "new PIL2JS.Box.Constant(new PIL2JS.NamedPair(%s, %s))",
       $key,
