@@ -1,5 +1,5 @@
 for <any all none one> -> $type {
-  Pugs::Internals::eval "
+  Pugs::Internals::eval_perl6 "
     sub JS::Root::$type (*\@vals) \{
       JS::inline('new PIL2JS.Box.Constant(function (args) \{
         args.pop()(new PIL2JS.Box.Constant(
@@ -10,6 +10,6 @@ for <any all none one> -> $type {
   ";
 }
 
-our &infix:<|> = &JS::Root::any;
-our &infix:<&> = &JS::Root::all;
-our &infix:<^> = &JS::Root::one;
+our &infix:<|> ::= &JS::Root::any;
+our &infix:<&> ::= &JS::Root::all;
+our &infix:<^> ::= &JS::Root::one;
