@@ -13,9 +13,9 @@ import qualified RuleJSON
 import qualified RuleUtility 
 import qualified RuleFunctorM
 import qualified RuleMonoid
-
+import qualified RulePerl6Class
 
 -- add your rules to this list
 userRules :: [RuleDef]
-userRules = userRulesXml ++ userRulesBinary ++ userRulesGeneric ++ userRulesGhcBinary  ++ RuleUtility.rules ++ RuleFunctorM.rules ++ RuleMonoid.rules ++ RulePerl5.rules ++ RuleJSON.rules ++ RuleYAML.rules
+userRules = userRulesXml ++ userRulesBinary ++ userRulesGeneric ++ userRulesGhcBinary  ++ RuleUtility.rules ++ RuleFunctorM.rules ++ RuleMonoid.rules ++ RulePerl5.rules ++ RuleJSON.rules ++ RuleYAML.rules ++ RulePerl6Class.rules
 
