@@ -14,7 +14,7 @@ import Foreign.Ptr
 import Control.Monad.Reader
 import qualified Data.ByteString.Char8 as Buf
 import qualified Data.ByteString as Bytes
-import UTF8
+import Pugs.Internals (encodeUTF8, decodeUTF8)
 
 type Buf = Buf.ByteString
 
@@ -40,21 +40,21 @@ class Typeable a => YAML a where
             evaluate (show (typeOf x))
         case ty of
             "()" -> return nilNode
-            _    -> return $ mkTagNode (tagHs ty) YamlNil
+            _    -> return $ mkTagNode (tagHs ty) ENil
     fromYAML :: YamlNode -> IO a
-    fromYAML MkYamlNode{nodeElem=x} = fromYAMLElem x
+    fromYAML = fromYAMLElem . n_elem
     fromYAMLElem :: YamlElem -> IO a
     fromYAMLElem e = fail $ "unhandled element: " ++ (show e)
 
 asYAMLseq :: YAMLClass -> [EmitAs YAMLVal] -> EmitAs YamlNode
 asYAMLseq c ps = do
     ps' <- sequence ps
-    return $ mkTagNode (tagHs c) (YamlSeq ps')
+    return $ mkTagNode (tagHs c) (ESeq ps')
 
 asYAMLmap :: YAMLClass -> [(YAMLKey, EmitAs YAMLVal)] -> EmitAs YamlNode
 asYAMLmap c ps = do
     ps' <- mapM asYAMLpair ps
-    return $ mkTagNode (tagHs c) (YamlMap ps')
+    return $ mkTagNode (tagHs c) (EMap ps')
     where
     asYAMLpair (k, v) = do
         k' <- asYAML k
@@ -62,14 +62,23 @@ asYAMLmap c ps = do
         return (k', v')
 
 fromYAMLmap :: YAML a => YamlNode -> IO [(String, a)]
-fromYAMLmap MkYamlNode{nodeElem=YamlMap m} = mapM fromYAMLpair m
+fromYAMLmap MkNode{n_elem=EMap m} = mapM fromYAMLpair m
     where
-    fromYAMLpair (MkYamlNode{nodeElem=YamlStr k}, v) = do
+    fromYAMLpair (MkNode{n_elem=EStr k}, v) = do
         v' <- fromYAML v
         return (unpackBuf k, v')
     fromYAMLpair e = fail $ "no parse: " ++ show e
 fromYAMLmap e = fail $ "no parse: " ++ show e
 
+fromYAMLmapBuf :: YAML a => YamlNode -> IO [(Buf.ByteString, a)]
+fromYAMLmapBuf MkNode{n_elem=EMap m} = mapM fromYAMLpair m
+    where
+    fromYAMLpair (MkNode{n_elem=EStr k}, v) = do
+        v' <- fromYAML v
+        return (k, v')
+    fromYAMLpair e = fail $ "no parse: " ++ show e
+fromYAMLmapBuf e = fail $ "no parse: " ++ show e
+
 asYAMLcls :: YAMLClass -> EmitAs YamlNode
 asYAMLcls c = return $ mkTagStrNode (tagHs c) c
 
@@ -77,7 +86,7 @@ tagHs :: YAMLClass -> String
 tagHs = ("tag:hs:" ++)
 
 deTag :: YamlNode -> YAMLClass
-deTag MkYamlNode{nodeTag=Just s} =
+deTag MkNode{n_tag=Just s} =
     case s' of
         't':'a':'g':':':'h':'s':':':tag -> tag
         tag                             -> error $ "not a Haskell tag: " ++ tag
@@ -90,31 +99,36 @@ instance YAML () where
 
 instance YAML Int where
     asYAML x = return $ mkTagStrNode "int" $ show x
-    fromYAMLElem (YamlStr x) = return $ read $ Buf.unpack x
+    fromYAMLElem (EStr x) = return $ read $ Buf.unpack x
+    fromYAMLElem e = failWith e
+
+instance YAML Word where
+    asYAML x = return $ mkTagStrNode "int" $ show x
+    fromYAMLElem (EStr x) = return $ read $ Buf.unpack x
     fromYAMLElem e = failWith e
 
 instance YAML Buf where
-    asYAML = return . mkNode . YamlStr
-    fromYAMLElem (YamlStr str) = return str
+    asYAML = return . mkNode . EStr
+    fromYAMLElem (EStr str) = return str
     fromYAMLElem e = failWith e
 
 instance YAML String where
-    asYAML = return .  mkTagNode "str" . YamlStr . Bytes.pack . encode
-    fromYAMLElem (YamlStr str) = return . fst . decode $ Bytes.unpack str
+    asYAML = return .  mkTagNode "str" . EStr . Buf.pack . encodeUTF8
+    fromYAMLElem (EStr str) = return . decodeUTF8 $ Buf.unpack str
     fromYAMLElem e = failWith e
 
 instance YAML Bool where
     asYAML True = return $ mkTagStrNode "bool#yes" "1"
     asYAML False = return $ mkTagStrNode "bool#no" "0"
-    fromYAML MkYamlNode{nodeTag=Just s} | s == packBuf "bool#yes" = return True
-    fromYAML MkYamlNode{nodeTag=Just s} | s == packBuf "bool#no"  = return False
-    fromYAML MkYamlNode{nodeElem=x} = fromYAMLElem x
-    fromYAMLElem (YamlStr x) = return (x /= packBuf "0")
+    fromYAML MkNode{n_tag=Just s} | s == packBuf "bool#yes" = return True
+    fromYAML MkNode{n_tag=Just s} | s == packBuf "bool#no"  = return False
+    fromYAML MkNode{n_elem=x} = fromYAMLElem x
+    fromYAMLElem (EStr x) = return (x /= packBuf "0")
     fromYAMLElem e = failWith e
 
 instance YAML Integer where 
     asYAML x = return $ mkTagStrNode "int" $ show x
-    fromYAMLElem (YamlStr x) = return $ read $ Buf.unpack x
+    fromYAMLElem (EStr x) = return $ read $ Buf.unpack x
     fromYAMLElem e = failWith e
 
 instance YAML Rational where 
@@ -122,7 +136,7 @@ instance YAML Rational where
         where
         x = numerator r
         y = denominator r
-    fromYAMLElem (YamlSeq [MkYamlNode{nodeElem=YamlStr x}, MkYamlNode{nodeElem=YamlStr y}]) =
+    fromYAMLElem (ESeq [MkNode{n_elem=EStr x}, MkNode{n_elem=EStr y}]) =
         return $ (read $ Buf.unpack x) % (read $ Buf.unpack y)
     fromYAMLElem e = failWith e
     
@@ -132,34 +146,34 @@ instance YAML Double where
         | show num == "-Infinity" = return $ mkTagStrNode "float#neginf" "-.Inf"
         | show num == "NaN"       = return $ mkTagStrNode "float#nan"    "-.NaN"
         | otherwise               = return $ mkTagStrNode "float"        $ show num
-    fromYAML MkYamlNode{nodeTag=Just s} | s == packBuf "float#inf"    = return $  1/0 -- "Infinity" 
-    fromYAML MkYamlNode{nodeTag=Just s} | s == packBuf "float#neginf" = return $ -1/0 -- "-Infinity" 
-    fromYAML MkYamlNode{nodeTag=Just s} | s == packBuf "float#nan"    = return $  0/0 -- "NaN" 
-    fromYAML MkYamlNode{nodeElem=x} = fromYAMLElem x
-    fromYAMLElem (YamlStr x) = return $ read $ Buf.unpack x
+    fromYAML MkNode{n_tag=Just s} | s == packBuf "float#inf"    = return $  1/0 -- "Infinity" 
+    fromYAML MkNode{n_tag=Just s} | s == packBuf "float#neginf" = return $ -1/0 -- "-Infinity" 
+    fromYAML MkNode{n_tag=Just s} | s == packBuf "float#nan"    = return $  0/0 -- "NaN" 
+    fromYAML MkNode{n_elem=x} = fromYAMLElem x
+    fromYAMLElem (EStr x) = return $ read $ Buf.unpack x
     fromYAMLElem e = failWith e
 
 instance (YAML a) => YAML (Maybe a) where
     asYAML (Just x) = asYAML x
     asYAML Nothing = return $ nilNode
-    fromYAML MkYamlNode{nodeElem=YamlNil} = return Nothing
+    fromYAML MkNode{n_elem=ENil} = return Nothing
     fromYAML x = return . Just =<< fromYAML x
-    fromYAMLElem YamlNil = return Nothing
+    fromYAMLElem ENil = return Nothing
     fromYAMLElem x = return . Just =<< fromYAMLElem x
 
 instance (YAML a) => YAML [a] where
     asYAML xs = do
         xs' <- mapM asYAML xs
-        (return . mkNode . YamlSeq) xs'
-    fromYAMLElem (YamlSeq s) = mapM fromYAML s
+        (return . mkNode . ESeq) xs'
+    fromYAMLElem (ESeq s) = mapM fromYAML s
     fromYAMLElem e = fail $ "no parse: " ++ show e
 
 instance (YAML a, YAML b) => YAML (a, b) where
     asYAML (x, y) = do
         x' <- asYAML x
         y' <- asYAML y
-        return $ mkNode (YamlSeq [x', y'])
-    fromYAMLElem (YamlSeq [x, y]) = do
+        return $ mkNode (ESeq [x', y'])
+    fromYAMLElem (ESeq [x, y]) = do
         x' <- fromYAML x
         y' <- fromYAML y
         return (x', y')
@@ -170,8 +184,8 @@ instance (YAML a, YAML b, YAML c) => YAML (a, b, c) where
         x' <- asYAML x
         y' <- asYAML y
         z' <- asYAML z
-        return $ mkNode (YamlSeq [x', y', z'])
-    fromYAMLElem (YamlSeq [x, y, z]) = do
+        return $ mkNode (ESeq [x', y', z'])
+    fromYAMLElem (ESeq [x, y, z]) = do
         x' <- fromYAML x
         y' <- fromYAML y
         z' <- fromYAML z
@@ -185,16 +199,16 @@ instance (Typeable a, YAML a) => YAML (TVar a) where
 
 asYAMLwith :: (YAML a, YAML b) => (a -> EmitAs b) -> a -> EmitAs YamlNode
 asYAMLwith f x = do
-    ptr  <- liftIO $ addressOf x
+    ptr  <- liftIO $ stableAddressOf x
     seen <- ask
     if IntSet.member ptr seen
-        then return nilNode{ nodeAnchor = MkYamlReference ptr } 
+        then return nilNode{ n_anchor = AReference ptr } 
         else do
             rv   <- local (IntSet.insert ptr) (asYAML =<< f x)
-            return rv{ nodeAnchor = MkYamlAnchor ptr }
+            return rv{ n_anchor = AAnchor ptr }
 
-addressOf :: a -> IO Int
-addressOf x = do
+stableAddressOf :: a -> IO Int
+stableAddressOf x = do
     ptr <- newStablePtr x
     return (castStablePtrToPtr ptr `minusPtr` (nullPtr :: Ptr ()))
 
