@@ -10,7 +10,9 @@ import Pugs.Compat ()
 import Pugs.Embed.Parrot ()
 import Pugs.Embed.Perl5 ()
 import Pugs.Run.Perl5 ()
+import Pugs.Parser.Charnames ()
 import Pugs.Parser.Program ()
+import Pugs.Lexer ()
 import Data.ByteString ()
 import Data.ByteString.Char8 ()
 import Data.Yaml.Syck ()
