@@ -121,6 +121,8 @@ import Foreign.Ptr
 import Foreign.C.Types
 import Data.Ratio
 import Data.Typeable
+import System.Posix.Internals
+import Foreign.C.Error
 
 failWith :: (Monad m) => String -> m a
 failWith s = fail $ "'" ++ s ++ "' not implemented on this platform."
@@ -186,19 +188,46 @@ removeLink _ = warnWith "unlink"
 setFileMode :: FilePath -> FileMode -> IO ()
 setFileMode _ _ = warnWith "chmod"
 
-data DirStream deriving (Typeable)
+newtype DirStream = DirStream (Ptr CDir)
+    deriving (Typeable)
 
 openDirStream :: FilePath -> IO DirStream
-openDirStream _ = failWith "opendir"
+openDirStream name =
+  withCString name $ \s -> do
+    dirp <- c_opendir s
+    return (DirStream dirp)
 
 readDirStream :: DirStream -> IO FilePath
-readDirStream _ = failWith "readdir"
+readDirStream (DirStream dirp) =
+  alloca $ \ptr_dEnt  -> loop ptr_dEnt
+ where
+  loop ptr_dEnt = do
+    resetErrno
+    r <- readdir dirp ptr_dEnt
+    if (r == 0)
+        then do
+            dEnt <- peek ptr_dEnt
+            if (dEnt == nullPtr) then return [] else do
+                entry <- (d_name dEnt >>= peekCString)
+                freeDirEnt dEnt
+                return entry
+        else do
+            errno <- getErrno
+            if (errno == eINTR) then loop ptr_dEnt else do
+                let (Errno eo) = errno
+                if (eo == end_of_dir)
+                    then return []
+                    else throwErrno "readDirStream"
 
 rewindDirStream :: DirStream -> IO ()
-rewindDirStream _ = failWith "rewinddir"
+rewindDirStream (DirStream dirp) = do
+    c_rewinddir dirp
+    return ()
 
 closeDirStream :: DirStream -> IO ()
-closeDirStream _ = failWith "closedir"
+closeDirStream (DirStream dirp) = do
+    c_closedir dirp
+    return ()
 
 -- Win32 specific
 
