@@ -1,4 +1,4 @@
-{-# OPTIONS_GHC -fglasgow-exts -fth -cpp #-}
+{-# OPTIONS_GHC -fglasgow-exts -fth -cpp -fallow-overlapping-instances #-}
 
 module Pugs.Compile.Haskell (
     genGHC,
@@ -51,13 +51,13 @@ compile (Stmts stmt rest) = [| do
     |] where
     argC = compile stmt
     argRest = compile rest
-compile (App (Var op) Nothing []) = [| op0 op [] |]
-compile (App (Var ('&':op)) Nothing [arg]) = [| do
+compile (App (Var var) Nothing []) | op <- cast var = [| op0 op [] |]
+compile (App (Var var) Nothing [arg]) | ('&':op) <- cast var = [| do
         val <- $(argC)
         op1 op val
     |] where
     argC = compile arg
-compile (App (Var ('&':op)) Nothing [arg1, arg2]) = [| do
+compile (App (Var var) Nothing [arg1, arg2]) | ('&':op) <- cast var = [| do
         val1 <- $(argC1)
         val2 <- $(argC2)
         op2 op val1 val2
