@@ -1,4 +1,4 @@
-{-# OPTIONS_GHC -fglasgow-exts -fallow-undecidable-instances -fno-warn-orphans -funbox-strict-fields -cpp -fno-warn-deprecations #-}
+{-# OPTIONS_GHC -fglasgow-exts -fallow-undecidable-instances -fno-warn-orphans -funbox-strict-fields -cpp -fno-warn-deprecations -fallow-overlapping-instances #-}
 
 module Pugs.Compile.PIL2 (
     PIL_Stmts(..), PIL_Stmt(..), PIL_Expr(..), PIL_Decl(..), PIL_Literal(..), PIL_LValue(..),
@@ -63,7 +63,7 @@ instance Compile Pad [PIL_Decl] where
         entries' <- mapM canCompile entries
         return $ concat entries'
         where
-        entries = sortBy padSort $ padToList pad
+        entries = sortBy padSort [ (cast var, ref) | (var, ref) <- padToList pad ]
         canCompile (name@('&':_), xs) | length xs > 1 = do
             fmap concat $ mapM (\x -> canCompile (name, [x])) xs
         canCompile (name@('&':_), [(_, sym)]) = do
@@ -126,7 +126,7 @@ instance Compile (String, [(TVar Bool, TVar VRef)]) PIL_Expr where
     compile (name, ((_, ref):_)) = do
         rv <- readRef =<< liftSTM (readTVar ref)
         case rv of
-            VCode sub   -> return $ PRawName (subName sub)
+            VCode sub   -> return $ PRawName (cast $ subName sub)
             _           -> return $ PRawName name
     compile (name, _) = return $ PRawName name
 
@@ -136,13 +136,15 @@ instance Compile Exp PIL_Stmts where
     compile (Ann Prag{} rest) = compile rest -- fmap (PPos pos rest) $ compile rest
     compile (Ann (Cxt cxt) rest) = enter cxt $ compile rest
     compile (Ann _ rest) = compile rest
-    compile (Sym _ "" rest) = compile rest
     compile (Stmts (Pad SOur _ exp) rest) = do
         compile $ mergeStmts exp rest
     compile (Stmts (Pad scope pad exp) rest) = do
-        padC    <- compile $ padToList pad
-        let symC = (map fst $ padToList pad) `zip` padC
-            exps = [ Syn ":=" [Var name, Var from] | (name, PRawName from) <- symC, name /= from ]
+        padC    <- compile [ (cast var :: String, ref) | (var, ref) <- padToList pad ]
+        let symC = (map (cast . fst) $ padToList pad) `zip` padC
+            exps = [ Syn ":=" [_Var name, _Var from]
+                   | (name, PRawName from) <- symC
+                   , name /= from
+                   ]
         expC    <- compile $ mergeStmts (foldl1 mergeStmts (exps ++ [exp])) rest
         return $ PPad scope symC expC
     compile exp = compileStmts exp
@@ -169,11 +171,11 @@ compileStmts exp = case exp of
     Stmts this (Syn "namespace" [Val (VStr sym), Val (VStr pkg), rest]) -> do
         thisC   <- enter cxtVoid $ compile this
         declC   <- enter cxtVoid $ compile decl
-        restC   <- enterPackage pkg $ compileStmts rest
+        restC   <- enterPackage (cast pkg) $ compileStmts rest
         return $ PStmts thisC $ PStmts declC restC
         where
           -- XXX - kludge.
-          decl = App (Var func) Nothing [(Val (VStr pkg))]
+          decl = App (_Var func) Nothing [(Val (VStr pkg))]
           func = "&" ++ (capitalize sym) ++ "::_create"
           capitalize []     = []
           capitalize (c:cs) = toUpper c:cs
@@ -197,7 +199,6 @@ instance Compile Exp PIL_Stmt where
     -- XXX: pragmas?
     compile (Ann Prag{} rest) = compile rest -- fmap (PPos pos rest) $ compile rest
     compile (Ann _ rest) = compile rest
-    compile (Sym _ "" rest) = compile rest
     compile Noop = return PNoop
     compile (Val val) = do
         cxt     <- asks envContext
@@ -221,7 +222,7 @@ instance Compile Exp PIL_Stmt where
         condC   <- cond'
         bodyC   <- compile body
         postC   <- compile post
-        funC    <- compile (Var "&statement_control:loop")
+        funC    <- compile (_Var "&statement_control:loop")
         return . PStmt . PExp $ PApp TCxtVoid funC Nothing
             [preC, pBlock condC, pBlock bodyC, pBlock postC]
     compile exp@(Syn "unless" _) = fmap (PStmt . PExp) $ compConditional exp
@@ -232,10 +233,10 @@ instance Compile Exp PIL_Stmt where
     compile (Syn "for" [exp, body]) = do
         expC    <- compile exp
         bodyC   <- compile body
-        funC    <- compile (Var "&statement_control:for")
+        funC    <- compile (_Var "&statement_control:for")
         return . PStmt . PExp $ PApp TCxtVoid funC Nothing [expC, bodyC]
-    compile (Syn "given" _) = compile (Var "$_") -- XXX
-    compile (Syn "when" _) = compile (Var "$_") -- XXX
+    compile (Syn "given" _) = compile (_Var "$_") -- XXX
+    compile (Syn "when" _) = compile (_Var "$_") -- XXX
     compile exp = fmap PStmt $ compile exp
 
 pBlock :: PIL_Stmts -> PIL_Expr
@@ -258,7 +259,7 @@ askTCxt = do
             CxtItem typ     -> TCxtItem typ
             CxtSlurpy typ   -> TCxtSlurpy typ
 
-instance (Show (m a), FunctorM m, Typeable1 m, Compile a b) => Compile (m a) (m b) where
+instance (Compile a b) => Compile [a] [b] where
     compile = fmapM compile
 
 instance (Compile a b, Compile a c) => Compile [a] (b, c) where
@@ -274,13 +275,12 @@ instance Compile Exp PIL_LValue where
     compile (Ann Prag{} rest) = compile rest
     compile (Ann (Cxt cxt) rest) = enter cxt $ compile rest
     compile (Ann _ rest) = compile rest
-    compile (Sym _ "" rest) = compile rest
     -- XXX: pragmas?
-    compile (Var name) = return $ PVar name
+    compile (Var name) = return $ _PVar name
     compile (Syn (sigil:"::()") exps) = do
-        compile $ App (Var "&Pugs::Internals::symbolic_deref") Nothing $
+        compile $ App (_Var "&Pugs::Internals::symbolic_deref") Nothing $
             (Val . VStr $ sigil:""):exps
-    compile (App (Var "&goto") (Just inv) args) = do
+    compile (App (Var var) (Just inv) args) | var == cast "&goto" = do
         cxt     <- askTCxt
         funC    <- compile inv
         argsC   <- enter cxtItemAny $ compile args
@@ -303,23 +303,23 @@ instance Compile Exp PIL_LValue where
         isLogicalLazy (PExp (PVar "&infix://"))  = True
         isLogicalLazy _ = False
     compile exp@(Syn "if" _) = compConditional exp
-    compile (Syn "{}" (x:xs)) = compile $ App (Var "&postcircumfix:{}") (Just x) xs
+    compile (Syn "{}" (x:xs)) = compile $ App (_Var "&postcircumfix:{}") (Just x) xs
     compile (Syn "[]" (x:xs)) = do
-        compile (App (Var "&postcircumfix:[]") (Just x) xs)
+        compile (App (_Var "&postcircumfix:[]") (Just x) xs)
     compile (Syn "," exps) = do
-        compile (App (Var "&infix:,") Nothing exps)
+        compile (App (_Var "&infix:,") Nothing exps)
     -- Minor hack, my $a = [] is parsed as my $a = [Noop], resulting in my $a =
     -- [undef], which is wrong.
     compile (Syn "\\[]" [Noop]) = do
-        compile (App (Var "&circumfix:[]") Nothing [])
+        compile (App (_Var "&circumfix:[]") Nothing [])
     compile (Syn "\\[]" exps) = do
-        compile (App (Var "&circumfix:[]") Nothing exps)
+        compile (App (_Var "&circumfix:[]") Nothing exps)
     compile (Syn name@(sigil:"{}") exps) | (sigil ==) `any` "$@%&" = do
-        compile (App (Var $ "&circumfix:" ++ name) Nothing exps)
+        compile (App (_Var $ "&circumfix:" ++ name) Nothing exps)
     compile (Syn "\\{}" exps) = do
-        compile (App (Var "&circumfix:{}") Nothing exps)
+        compile (App (_Var "&circumfix:{}") Nothing exps)
     compile (Syn "*" exps) = do
-        compile (App (Var "&prefix:*") Nothing exps)
+        compile (App (_Var "&prefix:*") Nothing exps)
     compile (Syn "=" [lhs, rhs]) = do
         lhsC <- enterLValue $ compile lhs
         rhsC <- enterRValue $ compile rhs
@@ -329,9 +329,9 @@ instance Compile Exp PIL_LValue where
         return $ PBind [lhsC] rhsC
     compile (Syn syn [lhs, exp]) | last syn == '=' = do
         let op = "&infix:" ++ init syn
-        compile $ Syn "=" [lhs, App (Var op) Nothing [lhs, exp]]
+        compile $ Syn "=" [lhs, App (_Var op) Nothing [lhs, exp]]
     compile (Syn "but" [obj, block]) =
-        compile $ App (Var "&Pugs::Internals::but_block") Nothing [obj, block]
+        compile $ App (_Var "&Pugs::Internals::but_block") Nothing [obj, block]
     compile exp@(Syn "namespace" _) = do
         -- XXX - Is there a better way to wrap Stmts as LValue?
         compile $ App (Syn "sub"
@@ -344,7 +344,7 @@ instance Compile Exp PIL_LValue where
     --   PApp { pNamedArgs = [...], pPositionalArgs = [...], ... }
     -- For now, using &Pugs::Internals::named_pair is probably ok.
     compile (Syn "named" kv@[_, _]) = do
-        compile $ App (Var "&Pugs::Internals::named_pair") Nothing kv
+        compile $ App (_Var "&Pugs::Internals::named_pair") Nothing kv
     compile exp = compError exp
 
 compLoop :: Exp -> Comp PIL_Stmt
@@ -352,7 +352,7 @@ compLoop (Syn name [cond, body]) = do
     cxt     <- askTCxt
     condC   <- enter (CxtItem $ mkType "Bool") $ compile cond
     bodyC   <- enter CxtVoid $ compile body
-    funC    <- compile (Var $ "&statement_control:" ++ name)
+    funC    <- compile (_Var $ "&statement_control:" ++ name)
     return . PStmt . PExp $ PApp cxt funC Nothing [pBlock condC, pBlock bodyC]
 compLoop exp = compError exp
 
@@ -362,20 +362,22 @@ compLoop exp = compError exp
 compConditional :: Exp -> Comp PIL_LValue
 compConditional (Syn name exps) = do
     [condC, trueC, falseC] <- compile exps
-    funC    <- compile $ Var ("&statement_control:" ++ name)
+    funC    <- compile $ _Var ("&statement_control:" ++ name)
     cxt     <- askTCxt
     return $ PApp cxt funC Nothing [condC, PThunk trueC, PThunk falseC]
 compConditional exp = compError exp
 
+_PVar :: Var -> PIL_LValue
+_PVar = PVar . cast
+
 {-| Compiles various 'Exp's to 'PIL_Expr's. -}
 instance Compile Exp PIL_Expr where
     compile (Ann Pos{} rest) = compile rest -- fmap (PPos pos rest) $ compile rest
     compile (Ann Prag{} rest) = compile rest
     compile (Ann (Cxt cxt) rest) = enter cxt $ compile rest
     compile (Ann _ rest) = compile rest
-    compile (Sym _ "" rest) = compile rest
     -- XXX: pragmas?
-    compile (Var name) = return . PExp $ PVar name
+    compile (Var name) = return . PExp $ _PVar name
     compile exp@(Val (VCode _)) = compile $ Syn "sub" [exp]
     compile (Val val) = fmap PLit $ compile val
     compile Noop = compile (Val undef)
@@ -394,6 +396,8 @@ instance Compile Exp PIL_Expr where
     compile (Syn "//" exp) = compile $ Syn "rx" exp
     compile (Syn "rx" [exp, _]) = compile exp -- XXX WRONG - use PCRE
     compile (Syn "subst" [exp, _, _]) = compile exp -- XXX WRONG - use PCRE
+    compile (Syn "|" [exp]) = compile exp -- XXX WRONG
+    compile (Syn "|<<" [exp]) = compile exp -- XXX WRONG
     compile exp@(App _ _ _) = fmap PExp $ compile exp
     compile exp@(Syn _ _) = fmap PExp $ compile exp
     compile exp = compError exp
@@ -412,7 +416,7 @@ instance Compile Val PIL_Literal where
     compile val = return $ PVal val
 
 -- utility functions
-padSort :: (Var, [(TVar Bool, TVar VRef)]) -> (String, [(a, b)]) -> Ordering
+padSort :: (String, [(TVar Bool, TVar VRef)]) -> (String, [(a, b)]) -> Ordering
 padSort (a, [(_, _)]) (b, [(_, _)])
     | (head a == ':' && head b == '&') = LT
     | (head b == ':' && head a == '&') = GT
