@@ -1,22 +1,30 @@
-{-# OPTIONS_GHC -fglasgow-exts #-}
+{-# OPTIONS_GHC -fglasgow-exts -fallow-overlapping-instances #-}
 module Pugs.Prim.Code (
-    op1CodeAssoc, op1CodeName, op1CodeArity, op1CodeBody, op1CodePos,
+    op1CodeAssoc, op1CodeName, op1CodeArity, op1CodeBody, op1CodePos, op1CodeSignature
 ) where
 import Pugs.AST
 import Pugs.Internals
 import Pugs.Pretty
+import qualified Pugs.Val as Val
 
 {- On Code -}
 
 op1CodeAssoc :: Val -> Eval Val
 op1CodeAssoc v = do
     code <- fromVal v
-    return . castV $ subAssoc code
+    return $ case subAssoc code of
+        ANil                    -> undef
+        AIrrelevantToParsing    -> undef
+        A_left                  -> castV "left"
+        A_right                 -> castV "right"
+        A_non                   -> castV "non"
+        A_chain                 -> castV "chain"
+        A_list                  -> castV "list"
 
 op1CodeName :: Val -> Eval Val
 op1CodeName v = do
     code <- fromVal v
-    return . castV $ subName code
+    return . VStr $ cast (subName code)
 
 op1CodeArity :: Val -> Eval Val
 op1CodeArity v = do
@@ -36,5 +44,10 @@ op1CodePos v = do
         Nothing  -> return VUndef
         Just env -> return $ castV $ pretty $ envPos env
 
+op1CodeSignature :: Val -> Eval Val
+op1CodeSignature v = do
+    code <- fromVal v
+    return . VV . Val.val . paramsToSig . subParams $ code
+
 {- On Code::Exp -}
 
