@@ -1,19 +1,20 @@
-{-# OPTIONS_GHC -fglasgow-exts #-}
+{-# OPTIONS_GHC -fglasgow-exts -fallow-overlapping-instances #-}
 
 module Pugs.Prim.Param (
     foldParam
 ) where
 import Pugs.AST
+import Pugs.Internals
 
 doFoldParam :: String -> String -> [Param] -> [Param]
 doFoldParam cxt [] []       = [(buildParam cxt "" "$?1" (Val VUndef)) { isLValue = False }]
-doFoldParam cxt [] (p:ps)   = ((buildParam cxt "" (strInc $ paramName p) (Val VUndef)) { isLValue = False }:p:ps)
+doFoldParam cxt [] (p:ps)   = ((buildParam cxt "" (strInc . cast $ paramName p) (Val VUndef)) { isLValue = False }:p:ps)
 doFoldParam cxt (s:name) ps = ((buildParam cxt [s] name (Val VUndef)) { isLValue = False } : ps)
 
 foldParam :: String -> Params -> Params
 foldParam "Named" = \ps -> (
-    (buildParam "Hash" "*" "@?0" (Val VUndef)):
-    (buildParam "Hash" "*" "%?0" (Val VUndef)):ps)
+    (buildParam "Any" "*" "@?0" (Val VUndef)):
+    (buildParam "Any" "*" "%?0" (Val VUndef)):ps)
 foldParam "List"    = doFoldParam "Any" "*@?1"
 foldParam ('r':'w':'!':"List") = \ps -> ((buildParam "List" "" "@?0" (Val VUndef)) { isLValue = True }:ps)
 foldParam ('r':'w':'!':str) = \ps -> ((buildParam str "" "$?1" (Val VUndef)) { isLValue = True }:ps)
@@ -22,9 +23,9 @@ foldParam ('?':str)
     | ('r':'w':'!':typ) <- str
     = \ps -> ((buildParam typ "?" "$?1" (Val VUndef)) { isLValue = True }:ps)
     | (('r':'w':'!':typ), "=$_") <- break (== '=') str
-    = \ps -> ((buildParam typ "?" "$?1" (Var "$_")) { isLValue = True }:ps)
+    = \ps -> ((buildParam typ "?" "$?1" (_Var "$_")) { isLValue = True }:ps)
     | (typ, "=$_") <- break (== '=') str
-    = \ps -> ((buildParam typ "?" "$?1" (Var "$_")) { isLValue = False }:ps)
+    = \ps -> ((buildParam typ "?" "$?1" (_Var "$_")) { isLValue = False }:ps)
     | (typ, ('=':def)) <- break (== '=') str
     = let readVal "Num" = Val . VNum . read
           readVal "Int" = Val . VInt . read
