@@ -1,66 +1,95 @@
-#!/usr/bin/perl
-
-# Simple YAML test harness written over Test::Harness::Straps.
-# Hacked up from mini_harness.plx in the Test::Harness dist.
-# (And some stuff stolen from prove, too.)
-
-# Please improve me!
-#
-# TODO:
-# 1. Modularize this.
-# 2. Get to work concurrently with 'make test'
-# 3. 'make smoke' make target that uploads the results of this
-#    to a server somewhere.
-
-
 package Test::Harness::YAML;
 use strict;
+use warnings;
 
+use Benchmark;
+use Best 0.05 [ [ qw/YAML::Syck YAML/], qw/LoadFile DumpFile/ ];
+use File::Spec;
 use Getopt::Long;
-use YAML;
+use List::Util 'shuffle';
 use Test::Harness;
 use Test::TAP::Model;
-use File::Spec;
-use Benchmark;
+
+# Package and global declarations
 our @ISA = qw(Test::TAP::Model);
 our $SMOKERFILE = ".smoker.yml";
+our %Config;
+$ENV{TEST_ALWAYS_CALLER} = 1;
+$Test::Harness::Verbose  = 1;
 
 $| = 1;
 
-$ENV{TEST_ALWAYS_CALLER} = 1;
-
-GetOptions \our %Config, qw(--output-file|o=s --dry|n --concurrent|j=i
-        --shuffle|s --recurse|r --ext=s@ --anonymous|a --exclude|X=s@);
-fixup_concurrency();
-$Test::Harness::Verbose  = 1;
-$Config{"output-file"} ||= "tests.yml";
-$Config{"recurse"} = 1 if not defined $Config{"recurse"};
-# Needed for smokeserv
-$Config{"pugs-path"} = $ENV{HARNESS_PERL};
-push @{$Config{"exclude"}}, 'Disabled' if not $Config{"exclude"} or not @{$Config{"exclude"}};
-if(!@ARGV) {
-    @ARGV = sort map glob, "t/*/*.t", "t/*/*/*.t", "ext/*/t/*.t"
+sub get_config {
+    GetOptions \%Config, qw(
+        --concurrent|j=i    --shuffle|s   --exclude|X=s@
+        --output-file|o=s   --recurse|r   --anonymous|a
+        --include=s@        --dry|n       --help|h
+    );
+    fix_config();
+    my $Usage = qq{Usage: $0 [OPTIONS] 
+        --help, -h              This help message.
+        --output-file=FILE, -o  Store results in FILE [default: $Config{"output-file"}]
+        --dry, -n               Show which tests would be run but don't run them
+        --concurrent=N, -j      Run N test jobs concurrently (MSWin requires Paralle::ForkManager)
+        --shuffle, -s           Run tests in random order
+        --recurse, -r           Recurse into directories on test include list
+        --incude=I1,[I2,...]    Include files
+        --exclude=E1,[E2,...]   Exclude files
+        --anonymous, -a         Do not include ~/.smoker.yml data in report
+    } . "\n";
+    die $Usage if $Config{help};
 }
 
-_build_ext_re();
-_build_exclude_re();
+sub fix_config {
+    $Config{"concurrent"} ||= $ENV{PUGS_TESTS_CONCURRENT} || 1;
+    local $@;
+    eval { require Parallel::ForkManager; };
+    if ($@) {
+        if ($Config{"concurrent"} > 1 && $^O =~ /MSWin32|msys/) { # On cygwin we are okay.
+            warn "Sorry, concurrency not supported on your platform\n";
+            $Config{"concurrent"} = 1;
+        }
+        require POSIX;
+    }
+    else {
+        no warnings 'redefine';
+        *run_children = sub {
+            my ($self, $child_count, $all_tests) = @_;
+            my $pm =  Parallel::ForkManager->new($child_count);
+            my $chunk_size = POSIX::ceil(@$all_tests / $child_count);
+
+            for my $child (1 .. $child_count) {
+                my @own_tests = splice @$all_tests, 0, $chunk_size;
+                my $pid = $pm->start and next;
+                # Inside child process now
+                $self->{_child_num} = $child;
+                $self->run_test($_) for @own_tests;
+                $self->emit_chunk();
+                $pm->finish;
+                # Back in parent process now
+                push @{ $self->{_children} }, $pid;
+            }
+            $self->gather_results();
+        }
+    }
+    $Config{"output-file"} ||= "tests.yml";
+    $Config{"recurse"}       = 1 if not defined $Config{"recurse"};
+    # Needed for smokeserv
+    $Config{"pugs-path"} = $ENV{HARNESS_PERL};
+    push @{$Config{"exclude"}}, 'Disabled' if not $Config{"exclude"} or not @{$Config{"exclude"}};
+    _build_include_re();
+    _build_exclude_re();
+}
+
+get_config();
+
+@ARGV = sort map glob, "t/*/*.t", "t/*/*/*.t", "ext/*/t/*.t" unless @ARGV;
 
 my $s = __PACKAGE__->new;
 $s->run;
 $s->emit;
 exit 0;
 
-
-sub fixup_concurrency {
-    $Config{"concurrent"} ||= $ENV{PUGS_TESTS_CONCURRENT} || 1;
-    if ($^O =~ /MSWin32|msys/) { # On cygwin we are okay.
-        warn "Sorry, concurrency not supported on your platform\n";
-        $Config{"concurrent"} = 1;
-        return;
-    }
-    require POSIX;
-}
-
 sub all_in {
     my $start = shift;
 
@@ -78,7 +107,7 @@ sub all_in {
             if ( -d $currfile ) {
                 push( @hits, all_in( $currfile ) ) if $Config{recurse};
             } else {
-                push( @hits, $currfile ) if $currfile =~ $Config{ext_regex};
+                push( @hits, $currfile ) if $currfile =~ $Config{include_re};
             }
         }
     } else {
@@ -88,19 +117,11 @@ sub all_in {
     return @hits;
 }
 
-sub shuffle {
-    # Fisher-Yates shuffle
-    my $i = @_;
-    while ($i) {
-        my $j = rand $i--;
-        @_[$i, $j] = @_[$j, $i];
-    }
-}
 
 # concurrency temp-file. FIXME: use a real temp file?
 sub emit_chunk {
     my($self) = @_;
-    YAML::DumpFile("tests.$$.yml", $self->structure);
+    DumpFile("tests.$$.yml", $self->structure);
 }
 
 sub emit {
@@ -108,7 +129,7 @@ sub emit {
     $self->{_timing}{end} = time;
     $self->{_timing}{duration} =
         $self->{_timing}{end} - $self->{_timing}{start};
-    YAML::DumpFile($Config{"output-file"}, {
+    DumpFile($Config{"output-file"}, {
             meat => $self->structure,
             map { $_ => $self->{"_$_"} } qw{
                 build_info smoker config revision timing
@@ -128,12 +149,12 @@ sub _build_exclude_re {
     $Config{exclude_re} = qr/($excl)/ if $excl;
 }
 
-sub _build_ext_re {
-    my @ext = map { split /,/ } @{ $Config{ext} };
-    s/^\.// foreach @ext;
-    @ext = ("t") unless @ext;
-    my $ext_regex = join( "|", map { quotemeta } @ext );
-    $Config{ext_regex} = qr/\.($ext_regex)$/;
+sub _build_include_re {
+    my @include = map { split /,/ } @{ $Config{include} };
+    s/^\.// for @include;
+    @include = ("t") unless @include;
+    my $include_re = join( "|", map { quotemeta } @include );
+    $Config{include_re} = qr/\.($include_re)$/;
 }
 
 sub _init {
@@ -152,8 +173,8 @@ sub _init {
 sub get_smoker {
     my($self) = @_;
     if (!$Config{anonymous}) {
-        $self->{_smoker} = eval { YAML::LoadFile($SMOKERFILE) } ||
-            eval { YAML::LoadFile(($ENV{HOME}||'')."/$SMOKERFILE") };
+        $self->{_smoker} = eval { LoadFile($SMOKERFILE) } ||
+            eval { LoadFile(($ENV{HOME}||'')."/$SMOKERFILE") };
         if (!$self->{_smoker}) {
             warn<<"AD";
 Smoker info not found. Please create a file named $SMOKERFILE
@@ -172,9 +193,11 @@ sub get_tests {
     @ARGV = File::Spec->curdir unless @ARGV;
     push( @tests, -d $_ ? all_in( $_ ) : $_ ) for @ARGV;
 
+    @tests = grep { $_ !~ $Config{exclude_re} } @tests if $Config{exclude_re};
+
     if ( @tests ) {
         if ($Config{shuffle}) {
-            shuffle(@tests)
+            @tests = shuffle(@tests);
         } else {
             # default FS order isn't guaranteed sorted; and sorting
             # helps diffing raw YAML results.
@@ -208,15 +231,9 @@ sub run {
 
 sub run_children {
     my ($self, $child_count, $all_tests) = @_;
-    my $chunk_size = POSIX::ceil(@$all_tests / ($child_count * 3 - 1));
+    my $chunk_size = POSIX::ceil(@$all_tests / $child_count);
     for my $child (1 .. $child_count) {
-        my $this_size = $chunk_size * 3;
-
-        # Heuristic: Most of the first tests (ext/) are slow,
-        # so we arbitrarily lower the first chunk by 1/3.
-        $this_size -= $chunk_size if $child == 1;
-
-        my @own_tests = splice @$all_tests, 0, $this_size;
+        my @own_tests = splice @$all_tests, 0, $chunk_size;
         defined(my $pid = fork) or die "Can't fork: $!";
         if ($pid) {
             push @{ $self->{_children} }, $pid;
@@ -240,7 +257,7 @@ sub gather_results {
         my $file = "tests.$pid.yml";
         warn sprintf "waiting for chunk #%d...\n", ++$kid; 
         waitpid($pid, 0) or die "waitpid: $!";
-        my $chunk = YAML::LoadFile($file) or die "can't parse chunk ($file)";
+        my $chunk = LoadFile($file) or die "can't parse chunk ($file)";
         push @{ $self->{meat}{test_files} }, @{$chunk->{test_files}};
         unlink $file or die "unlink: $!";
     }
@@ -258,3 +275,17 @@ sub run_test {
     } );
     warn "    ".timestr($t)."\n";
 }
+
+
+__END__
+# Simple YAML test harness written over Test::Harness::Straps.
+# Hacked up from mini_harness.plx in the Test::Harness dist.
+# (And some stuff stolen from prove, too.)
+
+# Please improve me!
+#
+# TODO:
+# 1. Modularize this.
+# 2. Get to work concurrently with 'make test'
+# 3. 'make smoke' make target that uploads the results of this
+#    to a server somewhere.
